==> spacy-3.0.5.tar.gz: spacy-3.0.5/spacy/cli/__init__.py <==
from wasabi import msg

from ._util import app, setup_cli  # noqa: F401

# These are the actual functions, NOT the wrapped CLI commands. The CLI commands
# are registered automatically and won't have to be imported here.
from .download import download  # noqa: F401
from .info import info  # noqa: F401
from .package import package  # noqa: F401
from .profile import profile  # noqa: F401
from .train import train_cli  # noqa: F401
from .pretrain import pretrain  # noqa: F401
from .debug_data import debug_data  # noqa: F401
from .debug_config import debug_config  # noqa: F401
from .debug_model import debug_model  # noqa: F401
from .evaluate import evaluate  # noqa: F401
from .convert import convert  # noqa: F401
from .init_pipeline import init_pipeline_cli  # noqa: F401
from .init_config import init_config, fill_config  # noqa: F401
from .validate import validate  # noqa: F401
from .project.clone import project_clone  # noqa: F401
from .project.assets import project_assets  # noqa: F401
from .project.run import project_run  # noqa: F401
from .project.dvc import project_update_dvc  # noqa: F401
from .project.push import project_push  # noqa: F401
from .project.pull import project_pull  # noqa: F401
from .project.document import project_document  # noqa: F401


@app.command("link", no_args_is_help=True, deprecated=True, hidden=True)
def link(*args, **kwargs):
    """As of spaCy v3.0, symlinks like "en" are deprecated. You can load trained
    pipeline packages using their full names or from a directory path."""
    msg.warn(
        "As of spaCy v3.0, model symlinks are deprecated. You can load trained "
        "pipeline packages using their full names or from a directory path."
    )

==> spacy-3.4.3.tar.gz: spacy-3.4.3/spacy/cli/__init__.py <==
from wasabi import msg

from ._util import app, setup_cli  # noqa: F401

# These are the actual functions, NOT the wrapped CLI commands. The CLI commands
# are registered automatically and won't have to be imported here.
from .download import download  # noqa: F401
from .info import info  # noqa: F401
from .package import package  # noqa: F401
from .profile import profile  # noqa: F401
from .train import train_cli  # noqa: F401
from .assemble import assemble_cli  # noqa: F401
from .pretrain import pretrain  # noqa: F401
from .debug_data import debug_data  # noqa: F401
from .debug_config import debug_config  # noqa: F401
from .debug_model import debug_model  # noqa: F401
from .debug_diff import debug_diff  # noqa: F401
from .evaluate import evaluate  # noqa: F401
from .convert import convert  # noqa: F401
from .init_pipeline import init_pipeline_cli  # noqa: F401
from .init_config import init_config, fill_config  # noqa: F401
from .validate import validate  # noqa: F401
from .project.clone import project_clone  # noqa: F401
from .project.assets import project_assets  # noqa: F401
from .project.run import project_run  # noqa: F401
from .project.dvc import project_update_dvc  # noqa: F401
from .project.push import project_push  # noqa: F401
from .project.pull import project_pull  # noqa: F401
from .project.document import project_document  # noqa: F401


@app.command("link", no_args_is_help=True, deprecated=True, hidden=True)
def link(*args, **kwargs):
    """As of spaCy v3.0, symlinks like "en" are not supported anymore. You can load trained
    pipeline packages using their full names or from a directory path."""
    msg.warn(
        "As of spaCy v3.0, model symlinks are not supported anymore. You can load trained "
        "pipeline packages using their full names or from a directory path."
    )
